@@ -17,6 +17,7 @@ const TelepathyClient = imports.telepathyClient;
 const UserTracker = imports.userTracker;
 const Utils = imports.utils;
 const NetworksManager = imports.networksManager;
+const InitialSetup = imports.initialSetup;
 
 const MAX_RETRIES = 3;
 
@@ -38,6 +39,7 @@ var Application = new Lang.Class({
         GLib.set_application_name('Polari');
         GLib.set_prgname('org.gnome.Polari');
         this._retryData = new Map();
+        this._nickTrackData = new Map();
         this._demons = [];
 
         this.add_main_option('start-client', 0,
@@ -71,10 +73,18 @@ var Application = new Lang.Class({
 
     isRoomFocused: function(room) {
         return this.active_window &&
-               this.active_window.is_active &&
+               this.active_window['is-active'] &&
                this.active_window.active_room == room;
     },
 
+    // Small wrapper to mark user-requested nick changes
+    setAccountNick: function(account, nick) {
+        account.set_nickname_async(nick, (a, res) => {
+            account.set_nickname_finish(res);
+        });
+        this._untrackNominalNick(account);
+    },
+
     _checkService: function(conn, name, opath, iface) {
         let flags = Gio.DBusProxyFlags.DO_NOT_LOAD_PROPERTIES |
                     Gio.DBusProxyFlags.DO_NOT_CONNECT_SIGNALS;
@@ -177,6 +187,8 @@ var Application = new Lang.Class({
             parameter_type: GLib.VariantType.new('o') },
           { name: 'discard-identify-password',
             parameter_type: GLib.VariantType.new('o') },
+          { name: 'show-emoji-picker',
+            accels: ['<Primary>e'] },
           { name: 'start-client',
             activate: Lang.bind(this, this._onStartClient) },
           { name: 'help',
@@ -271,24 +283,35 @@ var Application = new Lang.Class({
         this.activate_action('start-client', null);
 
         if (!this.active_window) {
-            let window = new MainWindow.MainWindow({ application: this });
-            window.connect('destroy', () => {
-                if (this._settings.get_boolean('run-in-background'))
-                    return;
-                this.emit('prepare-shutdown');
-            });
-            window.connect('notify::active-room',
-                           () => { this.emit('room-focus-changed'); });
-            window.connect('notify::is-active',
-                           () => { this.emit('room-focus-changed'); });
-            window.show_all();
+            if (this._needsInitialSetup()) {
+                let setupDialog = new InitialSetup.InitialSetupWindow({ application: this });
+                let id = this.connect('window-removed', () => {
+                    this.disconnect(id);
+                    this.activate();
+                });
+            } else {
+                let window = new MainWindow.MainWindow({ application: this });
+                window.connect('destroy', () => {
+                    if (this._settings.get_boolean('run-in-background'))
+                        return;
+                    this.emit('prepare-shutdown');
+                });
+                window.connect('notify::active-room',
+                               () => { this.emit('room-focus-changed'); });
+                window.connect('notify::is-active',
+                               () => { this.emit('room-focus-changed'); });
+            }
         }
+
         this.active_window.present();
     },
 
     vfunc_window_added: function(window) {
         this.parent(window);
 
+        if (!(window instanceof MainWindow.MainWindow))
+            return;
+
         let action = this.lookup_action('leave-current-room');
         window.connect('notify::active-room', () => {
             action.enabled = window.active_room != null;
@@ -397,6 +420,37 @@ var Application = new Lang.Class({
         });
     },
 
+    _touchFile: function(file) {
+        try {
+            file.get_parent().make_directory_with_parents(null);
+        } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS)) {
+            // not an error, carry on
+        }
+
+        let stream = file.create(0, null);
+        stream.close(null);
+    },
+
+    _needsInitialSetup: function() {
+        if (GLib.getenv('POLARI_FORCE_INITIAL_SETUP')) {
+            GLib.unsetenv('POLARI_FORCE_INITIAL_SETUP');
+            return true;
+        }
+
+        let f = Gio.File.new_for_path(GLib.get_user_cache_dir() +
+                                      '/polari/initial-setup-completed');
+        try {
+            this._touchFile(f);
+        } catch(e) {
+            if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
+                return false; // initial setup has completed
+            log('Failed to mark initial setup as completed: ' + e.message);
+        }
+
+        let savedRooms = this._settings.get_value('saved-channel-list');
+        return savedRooms.n_children() == 0;
+    },
+
     _updateUserListAction: function() {
         let room = this.active_window.active_room;
         let action = this.lookup_action('user-list');
@@ -432,6 +486,40 @@ var Application = new Lang.Class({
         this._maybePresent(time);
     },
 
+    _trackNominalNick: function(account) {
+        if (this._nickTrackData.has(account))
+            return;
+
+        let nominalNick = this._getTrimmedAccountName(account);
+        let baseNick = Polari.util_get_basenick(nominalNick);
+
+        let tracker = this._userStatusMonitor.getUserTrackerForAccount(account);
+        let contactsChangedId = tracker.connect('contacts-changed::' + baseNick,
+            (t, nick) => {
+                if (nick != nominalNick)
+                    return;
+
+                let contact = tracker.lookupContact(nick);
+                if (contact != null && contact.alias == nick)
+                    return;
+
+                this._untrackNominalNick(account);
+                account.set_nickname_async(nominalNick, (a, res) => {
+                    a.set_nickname_finish(res);
+                });
+            });
+        this._nickTrackData.set(account, { tracker, contactsChangedId });
+    },
+
+    _untrackNominalNick: function(account) {
+        let data = this._nickTrackData.get(account);
+        if (!data)
+            return;
+
+        data.tracker.disconnect(data.contactsChangedId);
+        this._nickTrackData.delete(account);
+    },
+
     _ensureRetryData: function(account) {
         let data = this._retryData.get(account.object_path);
         if (data)
@@ -482,6 +570,8 @@ var Application = new Lang.Class({
         if (retryData.retry++ >= MAX_RETRIES)
             return false;
 
+        this._trackNominalNick(account);
+
         let oldParams = account.dup_parameters_vardict().deep_unpack();
         let nick = oldParams['account'].deep_unpack();
 
@@ -661,7 +751,8 @@ var Application = new Lang.Class({
             ],
             artists: [
                 'Sam Hewitt <hewittsamuel@gmail.com>',
-                'Jakub Steiner <jimmac@gmail.com>'
+                'Jakub Steiner <jimmac@gmail.com>',
+                'Lapo Calamandrei <calamandrei@gmail.com>'
             ],
             translator_credits: _("translator-credits"),
             comments: _("An Internet Relay Chat Client for GNOME"),
