@@ -7,6 +7,7 @@ const Gspell = imports.gi.Gspell;
 const Gtk = imports.gi.Gtk;
 
 const ChatView = imports.chatView;
+const EmojiPicker = imports.emojiPicker;
 const IrcParser = imports.ircParser;
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
@@ -18,6 +19,7 @@ const MAX_NICK_UPDATE_TIME = 5; /* s */
 const MAX_LINES = 5;
 
 let _checker = null;
+let _emojiPicker = null;
 
 var ChatEntry = new Lang.Class({
     Name: 'ChatEntry',
@@ -36,6 +38,19 @@ var ChatEntry = new Lang.Class({
 
         PasteManager.DropTargetIface.addTargets(this, this);
 
+        this._emojiPickedId = 0;
+
+        this.connect('icon-press', Lang.bind(this, this._showEmojiPicker));
+        this.connect('unmap', () => {
+            if (this._emojiPickedId)
+                _emojiPicker.disconnect(this._emojiPickedId);
+            this._emojiPickedId = 0;
+        });
+
+        let app = Gio.Application.get_default();
+        let action = app.lookup_action('show-emoji-picker');
+        action.connect('activate', Lang.bind(this, this._showEmojiPicker));
+
         if (!_checker)
             _checker = new Gspell.Checker();
 
@@ -48,6 +63,28 @@ var ChatEntry = new Lang.Class({
         this._useDefaultHandler = false;
     },
 
+    _showEmojiPicker: function() {
+        if (!this.is_sensitive() || !this.get_mapped())
+            return;
+
+        if (!_emojiPicker)
+            _emojiPicker = new EmojiPicker.EmojiPicker();
+
+        if (!this._emojiPickedId)
+            this._emojiPickedId = _emojiPicker.connect('emoji-picked',
+                (w, emoji) => {
+                    this.delete_selection();
+                    let pos = this.insert_text(emoji, -1, this.get_position());
+                    this.set_position(pos);
+                    this.grab_focus_without_selecting();
+                });
+
+        let rect = this.get_icon_area(Gtk.EntryIconPosition.SECONDARY);
+        _emojiPicker.set_relative_to(this);
+        _emojiPicker.set_pointing_to(rect);
+        _emojiPicker.popup();
+    },
+
     get can_drop() {
         return true;
     },
@@ -249,7 +286,7 @@ var EntryArea = new Lang.Class({
         let toplevelFocus = this._chatEntry.get_toplevel().get_focus();
         return this.sensitive &&
                this._chatEntry.get_mapped() &&
-               !this._chatEntry.has_focus &&
+               !this._chatEntry['has-focus'] &&
                !(toplevelFocus instanceof Gtk.Entry);
     },
 
@@ -388,29 +425,20 @@ var EntryArea = new Lang.Class({
         this._nickLabel.width_chars = Math.max(nick.length, this._maxNickChars);
         this._nickLabel.label = nick;
 
-        let account = this._room.account;
-        account.set_nickname_async(nick, (a, res) => {
-            try {
-                a.set_nickname_finish(res);
-            } catch(e) {
-                logError(e, "Failed to change nick");
+        let app = Gio.Application.get_default();
+        app.setAccountNick(this._room.account, nick);
 
-                this._updateNick();
-                return;
-            }
-
-            // TpAccount:nickname is a local property which doesn't
-            // necessarily match the externally visible nick; telepathy
-            // doesn't consider failing to sync the two an error, so
-            // we give the server MAX_NICK_UPDATE_TIME seconds until
-            // we assume failure and revert back to the server nick
-            //
-            // (set_aliases() would do what we want, but it's not
-            // introspected)
-            Mainloop.timeout_add_seconds(MAX_NICK_UPDATE_TIME, () => {
-                this._updateNick();
-                return GLib.SOURCE_REMOVE;
-            });
+        // TpAccount:nickname is a local property which doesn't
+        // necessarily match the externally visible nick; telepathy
+        // doesn't consider failing to sync the two an error, so
+        // we give the server MAX_NICK_UPDATE_TIME seconds until
+        // we assume failure and revert back to the server nick
+        //
+        // (set_aliases() would do what we want, but it's not
+        // introspected)
+        Mainloop.timeout_add_seconds(MAX_NICK_UPDATE_TIME, () => {
+            this._updateNick();
+            return GLib.SOURCE_REMOVE;
         });
     },
 
@@ -422,7 +450,7 @@ var EntryArea = new Lang.Class({
         this._nickLabel.width_chars = Math.max(nick.length, this._maxNickChars);
         this._nickLabel.label = nick;
 
-        if (!this._nickEntry.is_focus)
+        if (!this._nickEntry['is-focus'])
             this._nickEntry.text = nick;
     },
 
